% ***********************************************************************
% D_POWER_SPECTRUM
% Calculates the power spectrum of a signal x, i.e |X(w)|, along with the
% corresponding frequency vector to plot the result.
%
% Input parameters:
%       x       Signal acquired (m or g).
%       dt      Sampling interval of signals (s).
%       tf      Duration of signal (s).
%
% OUPUT:
%       f     Frequency vector used to plot power spectrum.
%       Py    Power Spectral Density vector evaluated at given frequencies
%
% Copyright (C) 2007 Quanser Consulting Inc.
% Quanser Consulting Inc.
% ***********************************************************************
%
function [f,Py] = d_power_spectrum(x,dt,tf)
    % length of signal (samples)
    L = tf / dt;
    % sampling frequency (Hz)
    fs = 1 / dt;    
    % Compute the Fourier transform of the signal.
    y = fft(x);
    % Compute the two-sided spectrum P2. 
    P2 = abs(y/L);
    % Compute single-sided spectrum P1 based on P2 and even-valued signal length L
    n = floor(L/2)+1;
    Py = P2(1:n);
    Py(2:end-1) = 2*Py(2:end-1);
    % Define the frequency domain f and plot the single-sided amplitude spectrum P1.    
    f = fs*(0:(L/2))/L;
end
   