%
%% FFT_EVAL_ACC
% 
% Loads the desired position data and measured table data from the MAT 
% files. The power spectrum of the desired and measured positions is
% computed and plotted.
%
% Copyright (C) 2019 Quanser Consulting Inc.
% Quanser Consulting Inc.
%
%% INPUT
% Load position data into Matlab workspace
fname_pos = 'saved_data/data_XYZ_acc.mat';
load(fname_pos);
% min/max frequencies for plotting (Hz)
f_min = 1;
f_max = 10;
% sampling interval (s)
Ts = 0.001;
% Max Time (s)
tf = max(max(data_XYZ_acc(1,:)));
% 
%% LOAD DATA X
% desired X acceleration (g)
ax_des = data_XYZ_acc(2,:);
% accelerometer X measurement (g)
ax_meas = data_XYZ_acc(5,:);
%
%% LOAD DATA Y
% desired Y acceleration (g)
ay_des = data_XYZ_acc(3,:);
% accelerometer Y measurement (g)
ay_meas = data_XYZ_acc(6,:);
%
%% LOAD DATA Z
% desired Z acceleration (g)
az_des = data_XYZ_acc(4,:);
% accelerometer Y measurement (g)
az_meas = data_XYZ_acc(7,:);
% 
%% FFT
% Calculate power spectrum of desired acceleration
[fpx,Padx] = d_power_spectrum(ax_des,Ts,tf);
% Calculate power spectrum of measured acceleration
[fpx,Pamx] = d_power_spectrum(ax_meas,Ts,tf);
%
% Calculate power spectrum of desired acceleration
[fpy,Pady] = d_power_spectrum(ay_des,Ts,tf);
% Calculate power spectrum of measured acceleration
[fpy,Pamy] = d_power_spectrum(ay_meas,Ts,tf);
%
% Calculate power spectrum of desired acceleration
[fpz,Padz] = d_power_spectrum(az_des,Ts,tf);
% Calculate power spectrum of measured acceleration
[fpz,Pamz] = d_power_spectrum(az_meas,Ts,tf);
%
%% DISPLAY PLOT
figure(5);
plot(fpx,Padx,'b--',fpx,Pamx,'r-');
axis([f_min f_max 0 1.2*max(Pamx)]);
title('Power Spectral Density (FFT): X-Axis')
xlabel('Frequency (Hz)');
ylabel('Acceleration X (g^2/Hz)');
legend('desired','measured');
%
figure(6);
plot(fpy,Pady,'b--',fpy,Pamy,'r-');
axis([f_min f_max 0 1.2*max(Pamy)]);
title('Power Spectral Density (FFT): Y-Axis')
xlabel('Frequency (Hz)');
ylabel('Acceleration Y (g^2/Hz)');
legend('desired','measured');
%
figure(7);
plot(fpz,Padz,'b--',fpz,Pamz,'r-');
axis([f_min f_max 0 1.2*max(Pamz)]);
title('Power Spectral Density (FFT): Z-Axis')
xlabel('Frequency (Hz)');
ylabel('Acceleration Z (g^2/Hz)');
legend('desired','measured');
% 