%% FFT_EVAL_POS_XY
% 
% Loads the desired position data and measured table data from the MAT file 
% files. The power spectrum of the desired and measured positions is
% computed and plotted.
%
% Copyright (C) 2019 Quanser Consulting Inc.
% Quanser Consulting Inc.
%
%% INPUT
% Load position data into Matlab workspace
fname_pos = 'saved_data/data_XYZ_pos.mat';
load(fname_pos);
% min/max frequencies for plotting (Hz)
f_min = 1;
f_max = 10;
% sampling interval (s)
Ts = 0.001;
% Max Time (s)
tf = max(max(data_XYZ_pos(1,:)));
%
%% LOAD DATA X
% desired position (mm);
x_des = 1e3*data_XYZ_pos(2,:);
% resulting measured table position (mm)
x_meas = 1e3*data_XYZ_pos(5,:);
%
%% LOAD DATA Y
% desired position (mm);
y_des = 1e3*data_XYZ_pos(3,:);
% resulting measured table position (mm)
y_meas = 1e3*data_XYZ_pos(6,:);
%
%% LOAD DATA Z
% desired position (mm);
z_des = 1e3*data_XYZ_pos(4,:);
% resulting measured table position (mm)
z_meas = 1e3*data_XYZ_pos(7,:);

%% FFT
% Calculate power spectrum of desired position X
[fpx,Pxd] = d_power_spectrum(x_des,Ts,tf);
% Calculate power spectrum of measured position X
[fpx,Pxm] = d_power_spectrum(x_meas,Ts,tf);
% Calculate power spectrum of desired position Y
[fpy,Pyd] = d_power_spectrum(y_des,Ts,tf);
% Calculate power spectrum of measured position Y
[fpy,Pym] = d_power_spectrum(y_meas,Ts,tf);
% Calculate power spectrum of desired position Z
[fpz,Pzd] = d_power_spectrum(z_des,Ts,tf);
% Calculate power spectrum of measured position Z
[fpz,Pzm] = d_power_spectrum(z_meas,Ts,tf);
%
%% PLOT
figure(5);
plot(fpx,Pxd,'b--',fpx,Pxm,'r-');
axis([f_min f_max 0 1.2*max(Pxd)]);
title('FFT of desired and measured X position');
xlabel('Frequency (Hz)');
ylabel('Position X (m^2/Hz)');
legend('desired','measured');
%
figure(6);
plot(fpy,Pyd,'b--',fpy,Pym,'r-');
axis([f_min f_max 0 1.2*max(Pyd)]);
title('FFT of desired and measured Y position');
xlabel('Frequency (Hz)');
ylabel('Position Y (m^2/Hz)');
legend('desired','measured');
% 
figure(7);
plot(fpz,Pzd,'b--',fpz,Pzm,'r-');
% axis([f_min f_max 0 1.2*max(Pzd)]);
axis([f_min f_max 0 1.2]);
title('FFT of desired and measured Z position');
xlabel('Frequency (Hz)');
ylabel('Position Z (m^2/Hz)');
legend('desired','measured');
% 