%% MAKE_SINE_XYZ
%
% Generates custom sine wave at different amplitudes, frequencies, and for 
% a specified duration.
%
% Copyright (C) 2019 Quanser Consulting Inc.
% Quanser Consulting Inc.
%
%% INPUT
% sine wave amplitude for each excitation (mm)
Ad_x  = [5, 2.5, 1.5];
Ad_y = [4, 3, 2]; 
Ad_z = [2, 1.5, 1]; 
% axes sine wave excitation frequencies (Hz)
fd_x = [1, 3, 5];
fd_y = [2, 4, 6];
fd_z = [1.5, 2.5, 4];
% time duration (s)
t_dur = 3;
% sampling period (s/sample)
dt = 0.001;
%
%% MAKE SINE WAVE
% construct sine wave trajectory
[Tc_x, Xd_x_mm, Vd_x_mm, Ad_x_mm] = construct_sine_trajectory(fd_x, Ad_x, t_dur, dt);
[Tc_y, Xd_y_mm, Vd_y_mm, Ad_y_mm] = construct_sine_trajectory(fd_y, Ad_y, t_dur, dt);
[Tc_z, Xd_z_mm, Vd_z_mm, Ad_z_mm] = construct_sine_trajectory(fd_z, Ad_z, t_dur, dt);
% final trajectory time (s)
tf = max([max(Tc_x) max(Tc_y) max(Tc_z)]);

% HEXAPOD Commands
% Convert desired scaled position and acceleration for Hexapod
% Desired position (m)
Xd_x = Xd_x_mm;
Xd_y = Xd_y_mm;
Xd_z = Xd_z_mm;
% Desired acceleration (m/s^2)
Ad_x = Ad_x_mm / 1000;
Ad_y = Ad_y_mm / 1000;
Ad_z = Ad_z_mm / 1000;
%
%% DISPLAY PLOT
% plot generated sine wave trajectories
% x-axis
figure(3);
subplot(2,1,1);
plot(Tc_x,Xd_x_mm,'b-');
title('\bf{Generated Sine Wave X}')
xlabel('time (s)');
ylabel('position (mm)');
subplot(2,1,2);
plot(Tc_x,Ad_x,'b-');
xlabel('time (s)');
ylabel('acceleration (g)');
%
% y-axis
figure(4);
subplot(2,1,1);
plot(Tc_y,Xd_y_mm,'r-');
title('\bf{Generated Sine Wave Y}')
xlabel('time (s)');
ylabel('position (mm)');
subplot(2,1,2);
plot(Tc_y,Ad_y,'r-');
xlabel('time (s)');
ylabel('acceleration (g)');
% 
% z-axis
figure(5);
subplot(2,1,1);
plot(Tc_z,Xd_z_mm,'r-');
title('\bf{Generated Sine Wave Z}')
xlabel('time (s)');
ylabel('position (mm)');
subplot(2,1,2);
plot(Tc_y,Ad_y,'r-');
xlabel('time (s)');
ylabel('acceleration (g)');